# -*- coding: utf-8 -*-
import argparse
import os
import re
import glob

from frame_s2.postproc_helper import validate_inputs, tif_update_metadata, _str2bool
from frame_s2.qua_adapt import start_qua_adapt

def parse_arguments():
    parser = argparse.ArgumentParser(prog='qua_adapt_batch.py', description="this as a wrapper around qua_adapt.py")

    parser.add_argument("--out_file_prefix", type=str, help="outfolder + fileprefix for DEK images",
                        required=True)
    parser.add_argument("--in_file_prefix", type=str, help="infolder + fileprefix for DAY images",
                        required=True)
    parser.add_argument("--start_dekad", type=str, help="start dekad for out file generation",
                        required=False,
                        default=None)
    parser.add_argument("--S2", type=_str2bool, help="S2|(Modis|PROBA (smooth15)", default=True,
                        required=False)

    return parser.parse_args()


def main():
    args = parse_arguments()
    batch(args.out_file_prefix, args.in_file_prefix, args.start_dekad, args.S2)

def batch(out_file_prefix, in_file_prefix, start_dekad, S2):

    # initialize
    hist_gap = 0  # gap beteween current dekad and previous_out_qua_Dek
    batch_mode = False  # batchmode : process all using in/out folder data
    infiles_2_validate = []

    # handle in files
    #in_folder = os.path.dirname(in_file_prefix)
    day_file_lst = glob.glob(in_file_prefix + '*.tif')  # full paths in list
    day_file_lst = list(map(lambda full_path: os.path.basename(full_path), day_file_lst))  # only filenames in list
    in_dekad_lst = list(map(lambda fname: re.search('[0-9]{4}', fname).group(0), day_file_lst))  # get dekads out of filename format:yytt
    in_dekad_lst.sort()
    if start_dekad is not None:
        in_dekad_lst[:] = [dekad for dekad in in_dekad_lst if
                           dekad >= start_dekad]  # remove dekads < start_dekad, we do not process those
    in_file_lst = list(map(lambda dekad: "%s%s.tif" % (in_file_prefix, dekad), in_dekad_lst))
    infiles_2_validate.extend(in_file_lst)

    # get dekadel file to use. These file should be smaller than first in_dekad, but ofcourse it should exist
    dek_file_lst = glob.glob(out_file_prefix + '*.tif')
    dek_file_lst = list(map(lambda full_path: os.path.basename(full_path), dek_file_lst))  # only filenames in list
    out_dekad_lst = list(map(lambda fname: re.search('[0-9]{4}', fname).group(0),
                             dek_file_lst))  # get dekads out of filename format:yytt
    out_dekad_lst.sort()
    out_dekad_lst = [dekad for dekad in out_dekad_lst if dekad < in_dekad_lst[0]]  # only keep out_dekad < in_dekad
    if len(out_dekad_lst) <1:
        #not output dekad file found, so not historical information is available. Start with clean sheet
        previous_out_qua_dek = None
    else:
        hist_dekad = out_dekad_lst[-1]  # take last available out_Dekad < start_dekad to use as a history file
        previous_out_qua_dek = "%s%s.tif" % (out_file_prefix, hist_dekad)
        infiles_2_validate.extend(previous_out_qua_dek)


    #START processing
    for in_dekad in in_dekad_lst:
        quaday_img = "%s%s.tif" % (in_file_prefix, in_dekad)
        current_dek_img = "%s%s.tif" % (out_file_prefix, in_dekad)

        print(' day_file : %s\n hist_file : %s\n dek_file : %s' % (quaday_img, previous_out_qua_dek, current_dek_img))
        previous_out_qua_dek = start_qua_adapt(quaday_img, current_dek_img, previous_out_qua_dek, S2)


if __name__ == "__main__":
    main()