import argparse
from pyspark import SparkContext
from pyspark import SparkConf
import os

from frame_s2.pmax import start_pmax

def parse_arguments():

    parser = argparse.ArgumentParser(prog='pmax.py')

    parser.add_argument("--root_dir", type=str, help="output end-date",
                        required=True)
    parser.add_argument("--date_list_files", type=str, help="a file with dates to process",
                        required=True)
    parser.add_argument("--roi", type=str, help="the roi",
                        required=True)
    parser.add_argument("--period", type=str, help="period: 1, 10",
                        required=False,
                        default=1)
    parser.add_argument("--level", type=int, help="1:Lv1, 2:Lv2",
                        required=False,
                        default=2)
    return parser.parse_args()


def run_pmax(root_dir, roi, yyyymmdd, period=1, level=2):
    yymmdd = yyyymmdd[2:8]
    if not level in [1, 2]: raise Exception("Level is wrong! is %s, but should be 1 or 2" % level)
    if not period in [1, 10]: raise Exception("period is wrong! is %s, but should be 1 or 10" % period)
    if period == 1:
        s_dir = 's01'


    #for AFR and L2, the roi abbreviation is not in the filenames, for the other roi's it is.
    #For level 1 is just without ROI
    if level == 2:
        if roi == 'AFR':
            roi_prefix = 'L2_LTA_'      #L2_AFR -> L2_LTA
        else:
            roi_prefix = 'L2_%s_' % ( roi)
    if level == 1:
        roi_prefix = 'L1_'



    sr_file = os.path.join(root_dir, 'rad', '%sSR_%s.tif' % (roi_prefix, yymmdd))
    tmi_file = os.path.join(root_dir, 'tmi', '%sTMPMIN_%s.tif' % (roi_prefix, yymmdd))
    tma_file = os.path.join(root_dir, 'tma', '%sTMPMAX_%s.tif' % (roi_prefix, yymmdd))
    npm_file = os.path.join(root_dir, 'npm', s_dir, 'L%s_%s_NPM_%s.tif' % (level, roi, yymmdd)) #also put AFR into the name
    npm = start_pmax(sr_file, tmi_file, tma_file, npm_file, yyyymmdd, yyyymmdd, 2, 0.5, 0, 1, 0 )

def main():
    args = parse_arguments()
    print(args)

    sc_conf = SparkConf()
    sc = SparkContext(conf=sc_conf)

    try:
        with open(args.date_list_files) as f:
            date_list = [line.rstrip() for line in f]           #remove newlines at the end
        #sometimes doubles are in the file, use a set to remove the doubles
        date_set = set(date_list)
        date_list = list(date_set)
        number_of_dates = len(date_list)

        if number_of_dates > 0:
            pmax_rdd = sc.parallelize(date_list, len(date_list))
            pmax_rdd.foreach(lambda yyyymmdd: run_pmax(args.root_dir, args.roi, yyyymmdd, level = args.level, period = 1))

    finally:
        sc.stop()


if __name__ == "__main__":
    main()

